﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace GraticuleVsMapUnit
{
    public partial class Form1 : Form
    {
        ShapeFileFeatureLayer countriesLayer;
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;

            // Load countries on the screen
            countriesLayer = new ShapeFileFeatureLayer(@"C:\Program Files (x86)\ThinkGeo\Map Suite Desktop Evaluation Edition 6.0\Samples\SampleData\Data\Countries02.shp");
            countriesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            countriesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay countriesOverlay = new LayerOverlay();
            countriesOverlay.Layers.Add("countries", countriesLayer);
            winformsMap1.Overlays.Add("shapeOverlay", countriesOverlay);

            // Add a graticule adornment layer
            GraticuleAdornmentLayer graticuleAdornmentLayer = new GraticuleAdornmentLayer();
            graticuleAdornmentLayer.GraticuleLineStyle.OuterPen.Color = GeoColor.FromArgb(125, GeoColor.StandardColors.Blue);
            graticuleAdornmentLayer.GraticuleLineStyle.CenterPen.Color = GeoColor.FromArgb(125, GeoColor.StandardColors.Blue);

            winformsMap1.AdornmentOverlay.Layers.Add("graticule", graticuleAdornmentLayer);
            winformsMap1.CurrentExtent = new RectangleShape(-180, 90, 180, -90);
            winformsMap1.Refresh();
        }

        private void btnMapUnit_Click(object sender, EventArgs e)
        {
            GraticuleAdornmentLayer graticuleAdornmentLayer = (GraticuleAdornmentLayer)winformsMap1.AdornmentOverlay.Layers["graticule"];

            if (winformsMap1.MapUnit == GeographyUnit.DecimalDegree)
            {
                winformsMap1.MapUnit = GeographyUnit.Meter;
                ((Button)sender).Text = "Spherical Mercator";

                Proj4Projection graticuleProjection = new Proj4Projection();
                graticuleProjection.InternalProjectionParametersString = ManagedProj4Projection.GetWgs84ParametersString();
                graticuleProjection.ExternalProjectionParametersString = ManagedProj4Projection.GetSphericalMercatorParametersString();
                graticuleProjection.Open();

                graticuleAdornmentLayer.Projection = graticuleProjection;
            }
            else
            {
                winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
                ((Button)sender).Text = "Decimal Degrees";

                graticuleAdornmentLayer.Projection = null;
            }

            countriesLayer.FeatureSource.Projection = graticuleAdornmentLayer.Projection;
            winformsMap1.CurrentExtent = countriesLayer.GetBoundingBox();
            winformsMap1.Refresh();
        }

        private void winformsMap1_MouseMove(object sender, MouseEventArgs e)
        {
            PointShape pointShape = ExtentHelper.ToWorldCoordinate(winformsMap1.CurrentExtent, new ScreenPointF(e.X, e.Y), winformsMap1.Width, winformsMap1.Height);

            if (winformsMap1.MapUnit == GeographyUnit.DecimalDegree)
            {
                toolStripStatusLabel1.Text = "(Lat/Long) X:" + Math.Round(pointShape.X, 4) + " Y:" + Math.Round(pointShape.Y, 4);
            }
            else
            {
                toolStripStatusLabel1.Text = "(Spherical Mercator) X:" + Math.Round(pointShape.X, 4) + " Y:" + Math.Round(pointShape.Y, 4);
            }
        }
    }
}
